# ModelFiles


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**structure_file** | **str, none_type** |  | [optional] 
**systems_file** | **str, none_type** |  | [optional] 
**map_file** | **str, none_type** |  | [optional] 
**gltf_file** | **str, none_type** |  | [optional] 
**gltf_with_openings_file** | **str, none_type** |  | [optional] 
**bvh_tree_file** | **str, none_type** |  | [optional] 
**viewer_360_file** | **str, none_type** |  | [optional] 
**xkt_file** | **str, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


